# Changelog

## [0.4.0](https://github.com/koboriakira/lotion/compare/v0.3.0...v0.4.0) (2024-12-15)


### Features

* プロパティを空欄で更新できる ([#26](https://github.com/koboriakira/lotion/issues/26)) ([7f2f999](https://github.com/koboriakira/lotion/commit/7f2f9993a1ad4648ddeb102d3923963a1e3d0d8f))

## [0.3.0](https://github.com/koboriakira/lotion/compare/v0.2.0...v0.3.0) (2024-12-15)


### Features

* ユニークIDに対応 ([#23](https://github.com/koboriakira/lotion/issues/23)) ([566eae0](https://github.com/koboriakira/lotion/commit/566eae0461a9bde6542c9dbc6cdbf7a71dd58e74))
* ロールアップのあるページに対応 ([#22](https://github.com/koboriakira/lotion/issues/22)) ([ab0ce93](https://github.com/koboriakira/lotion/commit/ab0ce93422eb2d1a8cbc81a10ad333a9fd897ec3))
* 数式プロパティの入ったページを操作可能にする ([#20](https://github.com/koboriakira/lotion/issues/20)) ([d3709df](https://github.com/koboriakira/lotion/commit/d3709dfabc2bb6c1e085e8c6fb38390b78793ba4))

## [0.2.0](https://github.com/koboriakira/lotion/compare/v0.1.0...v0.2.0) (2024-12-14)


### Features

* マルチセレクトを指定できるようにする ([#16](https://github.com/koboriakira/lotion/issues/16)) ([312b39e](https://github.com/koboriakira/lotion/commit/312b39ee18730bb4a5e510f483c940316f8e09b2))
* 名前を指定してセレクトを取得して利用する ([#14](https://github.com/koboriakira/lotion/issues/14)) ([9a14d4c](https://github.com/koboriakira/lotion/commit/9a14d4cb1ff1135085e44df45b734af230ab80a8))

## 0.1.0 (2024-12-14)


### Bug Fixes

* 正しいキャメルケースに修正 ([#12](https://github.com/koboriakira/lotion/issues/12)) ([9ffbb91](https://github.com/koboriakira/lotion/commit/9ffbb91cfc0c22bdcecf607e5055b052b53e0e61))
